@@ -1,6 +1,6 @@
 /*
-	FATSort, utility for sorting FAT directory structures
-	Copyright (C) 2004 Boris Leidner <fatsort(at)formenos.de>
+	FATDefrag, utility for defragmentation of FAT file systems
+	Copyright (C) 2013 Boris Leidner <fatdefrag(at)formenos.de>
 
 	This program is free software; you can redistribute it and/or
 	modify it under the terms of the GNU General Public License
@@ -170,6 +170,12 @@ int32_t read_bootsector(FILE *fd, struct sBootSector *bs) {
 	assert(fd != NULL);
 	assert(bs != NULL);
 
+	// seek to beginning of fs
+	if (fs_seek(fd, 0, SEEK_SET) == -1) {
+		stderror();
+		return -1;
+	}
+
 	if (fs_read(bs, sizeof(struct sBootSector), 1, fd) < 1) {
 		if (feof(fd)) {
 			myerror("Boot sector is too short!");
@@ -187,6 +193,85 @@ int32_t read_bootsector(FILE *fd, struct sBootSector *bs) {
 	return 0;
 }
 
+int32_t writeBootSector(struct sFileSystem *fs) {
+/*
+	write boot sector
+*/
+
+	// seek to beginning of fs
+	if (fs_seek(fs->fd, 0, SEEK_SET) == -1) {
+		stderror();
+		return -1;
+	}
+
+	// write boot sector
+	if (fs_write(&(fs->bs), sizeof(struct sBootSector), 1, fs->fd) < 1) {
+		stderror();
+		return -1;
+	}
+
+	//  update backup boot sector for FAT32 file systems
+	if (fs->FATType == FATTYPE_FAT32) {
+		// seek to beginning of backup boot sector
+		if (fs_seek(fs->fd, SwapInt16(fs->bs.FATxx.FAT32.BS_BkBootSec) * fs->sectorSize, SEEK_SET) == -1) {
+			stderror();
+			return -1;
+		}
+
+		// write backup boot sector
+		if (fs_write(&(fs->bs), sizeof(struct sBootSector), 1, fs->fd) < 1) {
+			stderror();
+			return -1;
+		}
+	}
+
+	return 0;
+}
+
+int32_t readFSInfo(struct sFileSystem *fs, struct sFSInfo *fsInfo) {
+/*
+	reads FSInfo structure
+*/
+
+	assert(fs != NULL);
+	assert(fsInfo != NULL);
+
+	// seek to beginning of FSInfo structure
+	if (fs_seek(fs->fd, SwapInt16(fs->bs.FATxx.FAT32.BS_FSInfo) * fs->sectorSize, SEEK_SET) == -1) {
+		stderror();
+		return -1;
+	}
+
+	if (fs_read(fsInfo, sizeof(struct sFSInfo), 1, fs->fd) < 1) {
+		stderror();
+		return -1;
+	}
+
+	return 0;
+}
+
+int32_t writeFSInfo(struct sFileSystem *fs, struct sFSInfo *fsInfo) {
+/*
+	write FSInfo structure
+*/
+	assert(fs != NULL);
+	assert(fsInfo != NULL);
+
+	// seek to beginning of FSInfo structure
+	if (fs_seek(fs->fd, SwapInt16(fs->bs.FATxx.FAT32.BS_FSInfo) * fs->sectorSize, SEEK_SET) == -1) {
+		stderror();
+		return -1;
+	}
+
+	// write boot sector
+	if (fs_write(fsInfo, sizeof(struct sFSInfo), 1, fs->fd) < 1) {
+		stderror();
+		return -1;
+	}
+
+	return 0;
+}
+
 int32_t getCountOfClusters(struct sBootSector *bs) {
 /*
 	calculates count of clusters
@@ -242,6 +327,121 @@ int32_t getFATType(struct sBootSector *bs) {
 	}
 }
 
+u_int16_t isFreeCluster(const u_int32_t data) {
+/*	
+	checks whether data marks a free cluster
+*/
+
+	    return (data & 0x0FFFFFFF) == 0;
+}
+
+u_int16_t isEOC(struct sFileSystem *fs, const u_int32_t data) {
+/*	
+	checks whether data marks the end of a cluster chain
+*/
+
+	assert(fs != NULL);
+
+	if(fs->FATType == FATTYPE_FAT12) {
+	    if(data >= 0x0FF8)
+		return 1;
+	} else if(fs->FATType == FATTYPE_FAT16) {
+	    if(data >= 0xFFF8)
+		return 1;
+	} else if (fs->FATType == FATTYPE_FAT32) {
+	    if((data & 0x0FFFFFFF) >= 0x0FFFFFF8)
+		return 1;
+	}
+
+	return 0;
+}
+
+u_int16_t isBadCluster(struct sFileSystem *fs, const u_int32_t data) {
+/*
+	checks whether data marks a bad cluster
+*/
+	assert(fs != NULL);
+
+	if(fs->FATType == FATTYPE_FAT12) {
+	    if(data == 0xFF7)
+		return 1;
+	} else if(fs->FATType == FATTYPE_FAT16) {
+	    if(data == 0xFFF7)
+		return 1;
+	} else if (fs->FATType == FATTYPE_FAT32) {
+	    if ((data & 0x0FFFFFFF) == 0x0FFFFFF7)
+		return 1;
+	}
+
+	return 0;
+}
+
+
+void *readFAT(struct sFileSystem *fs, u_int16_t nr) {
+/*
+	reads a FAT from file system fs
+*/
+
+	assert(fs != NULL);
+	assert(nr < fs->bs.BS_NumFATs);
+
+	u_int32_t FATSizeInBytes;
+	off_t BSOffset;
+
+	void *FAT;
+
+	FATSizeInBytes = fs->FATSize * fs->sectorSize;
+
+	if ((FAT=malloc(FATSizeInBytes))==NULL) {
+		stderror();
+		return NULL;
+	}
+	BSOffset = (off_t)SwapInt16(fs->bs.BS_RsvdSecCnt) * SwapInt16(fs->bs.BS_BytesPerSec);
+	if (fs_seek(fs->fd, BSOffset + nr * FATSizeInBytes, SEEK_SET) == -1) {
+		myerror("Seek error!");
+		free(FAT);
+		return NULL;
+	}
+	if (fs_read(FAT, FATSizeInBytes, 1, fs->fd) < 1) {
+		myerror("Failed to read from file!");
+		free(FAT);
+		return NULL;
+	}
+
+	return FAT;
+
+}
+
+int32_t writeFAT(struct sFileSystem *fs, void *fat) {
+/*
+	write FAT to file system
+*/
+
+	assert(fs != NULL);
+	assert(fat != NULL);
+
+	u_int32_t FATSizeInBytes, nr;
+	off_t BSOffset;
+
+	FATSizeInBytes = fs->FATSize * fs->sectorSize;
+
+	BSOffset = (off_t)SwapInt16(fs->bs.BS_RsvdSecCnt) * SwapInt16(fs->bs.BS_BytesPerSec);
+
+	// write all FATs!
+	for(nr=0; nr< fs->bs.BS_NumFATs; nr++) {
+		if (fs_seek(fs->fd, BSOffset + nr * FATSizeInBytes, SEEK_SET) == -1) {
+			myerror("Seek error!");
+			return -1;
+		}
+		if (fs_write(fat, FATSizeInBytes, 1, fs->fd) < 1) {
+			myerror("Failed to read from file!");
+			return -1;
+		}
+	}
+
+	return 0;
+}
+
 int32_t checkFATs(struct sFileSystem *fs) {
 /*
 	checks whether all FATs have the same content
@@ -343,7 +543,7 @@ int32_t getFATEntry(struct sFileSystem *fs, u_int32_t cluster, u_int32_t *data)
 		break;
 	case FATTYPE_FAT16:
 		FATOffset = (off_t)cluster * 2;
-		BSOffset = (off_t)SwapInt16(fs->bs.BS_RsvdSecCnt) * SwapInt16(fs->bs.BS_BytesPerSec) + FATOffset;
+		BSOffset = (off_t) SwapInt16(fs->bs.BS_RsvdSecCnt) * SwapInt16(fs->bs.BS_BytesPerSec) + FATOffset;
 		if (fs_seek(fs->fd, BSOffset, SEEK_SET) == -1) {
 			myerror("Seek error!");
 			return -1;
@@ -356,7 +556,7 @@ int32_t getFATEntry(struct sFileSystem *fs, u_int32_t cluster, u_int32_t *data)
 		break;
 	case FATTYPE_FAT12:
 		FATOffset = (off_t) cluster + (cluster / 2);
-		BSOffset = (off_t)SwapInt16(fs->bs.BS_RsvdSecCnt) * SwapInt16(fs->bs.BS_BytesPerSec) + FATOffset;
+		BSOffset = (off_t) SwapInt16(fs->bs.BS_RsvdSecCnt) * SwapInt16(fs->bs.BS_BytesPerSec) + FATOffset;
 		if (fs_seek(fs->fd, BSOffset, SEEK_SET) == -1) {
 			myerror("Seek error!");
 			return -1;
@@ -396,6 +596,47 @@ off_t getClusterOffset(struct sFileSystem *fs, u_int32_t cluster) {
 
 }
 
+void *readCluster(struct sFileSystem *fs, u_int32_t cluster) {
+/*
+	read cluster from file system
+*/
+	void *dummy;
+
+	if (fs_seek(fs->fd, getClusterOffset(fs, cluster), SEEK_SET) != 0) {
+		stderror();
+		return NULL;
+	}
+
+	if ((dummy = malloc(fs->clusterSize)) == NULL) {
+		stderror();
+		return NULL;
+	}
+
+	if ((fs_read(dummy, fs->clusterSize, 1, fs->fd)<1)) {
+		myerror("Failed to read cluster!");
+		return NULL;
+	}
+
+	return dummy;
+}
+
+int32_t writeCluster(struct sFileSystem *fs, u_int32_t cluster, void *data) {
+/*
+	write cluster to file systen
+*/
+	if (fs_seek(fs->fd, getClusterOffset(fs, cluster), SEEK_SET) != 0) {
+		stderror();
+		return -1;
+	}
+
+	if (fs_write(data, fs->clusterSize, 1, fs->fd)<1) {
+		stderror();
+		return -1;
+	}
+
+	return 0;
+}
+
 int32_t parseEntry(struct sFileSystem *fs, union sDirEntry *de) {
 /*
 	parses one directory entry
@@ -593,6 +834,22 @@ int32_t openFileSystem(char *path, u_int32_t mode, struct sFileSystem *fs) {
 	return 0;
 }
 
+int32_t syncFileSystem(struct sFileSystem *fs) {
+/*
+	sync file system
+*/
+	if (fflush(fs->fd) != 0) {
+		myerror("Could not flush stream!");
+		return -1;
+	}
+	if (fsync(fileno(fs->fd)) != 0) {
+		myerror("Could not sync file descriptor!");
+		return -1;
+	}
+
+	return 0;
+}
+
 int32_t closeFileSystem(struct sFileSystem *fs) {
 /*
 	closes file system
