@@ -1,6 +1,6 @@
 /*
-	FATSort, utility for sorting FAT directory structures
-	Copyright (C) 2004 Boris Leidner <fatsort(at)formenos.de>
+	FATDefrag, utility for defragmentation of FAT file systems
+	Copyright (C) 2013 Boris Leidner <fatdefrag(at)formenos.de>
 
 	This program is free software; you can redistribute it and/or
 	modify it under the terms of the GNU General Public License
@@ -157,6 +157,17 @@ struct sBootSector {
 	u_int16_t BS_EndOfBS;		// marks end of bootsector
 } __attribute__((packed));
 
+// FAT32 FSInfo structure
+struct sFSInfo {
+	u_int32_t FSI_LeadSig;
+	u_int8_t FSI_Reserved1[480];
+	u_int32_t FSI_StrucSig;
+	u_int32_t FSI_Free_Count;
+	u_int32_t FSI_Nxt_Free;
+	u_int8_t FSI_Reserved2[12];
+	u_int32_t FSI_TrailSig;
+} __attribute__((packed));
+
 // holds information about the file system
 struct sFileSystem {
 	FILE *fd;
@@ -183,6 +194,12 @@ struct sFileSystem {
 // opens file system and calculates file system information
 int32_t openFileSystem(char *path, u_int32_t mode, struct sFileSystem *fs);
 
+// update boot sector
+int32_t writeBootSector(struct sFileSystem *fs);
+
+// sync file system
+int32_t syncFileSystem(struct sFileSystem *fs);
+
 // closes file system
 int32_t closeFileSystem(struct sFileSystem *fs);
 
@@ -192,6 +209,27 @@ int32_t check_bootsector(struct sBootSector *bs);
 // retrieves FAT entry for a cluster number
 int32_t getFATEntry(struct sFileSystem *fs, u_int32_t cluster, u_int32_t *data);
 
+// read FAT from file system
+void *readFAT(struct sFileSystem *fs, u_int16_t nr);
+
+// write FAT to file system
+int32_t writeFAT(struct sFileSystem *fs, void *fat);
+
+// read cluster from file systen
+void *readCluster(struct sFileSystem *fs, u_int32_t cluster);
+
+// write cluster to file systen
+int32_t writeCluster(struct sFileSystem *fs, u_int32_t cluster, void *data);
+
+// checks whether data marks a free cluster
+u_int16_t isFreeCluster(const u_int32_t data);
+
+// checks whether data marks the end of a cluster chain
+u_int16_t isEOC(struct sFileSystem *fs, const u_int32_t data);
+
+// checks whether data marks a bad cluster
+u_int16_t isBadCluster(struct sFileSystem *fs, const u_int32_t data);
+
 // returns the offset of a specific cluster in the data region of the file system
 off_t getClusterOffset(struct sFileSystem *fs, u_int32_t cluster);
 
@@ -204,4 +242,10 @@ u_char calculateChecksum (char *sname);
 // checks whether all FATs have the same content
 int32_t checkFATs(struct sFileSystem *fs);
 
+// reads FSInfo structure
+int32_t readFSInfo(struct sFileSystem *fs, struct sFSInfo *fsInfo);
+
+// write FSInfo structure
+int32_t writeFSInfo(struct sFileSystem *fs, struct sFSInfo *fsInfo);
+
 #endif // __FAT_fs_h__
