@@ -14,7 +14,7 @@
 
 	You should have received a copy of the GNU General Public License
 	along with this program; if not, write to the Free Software
-	Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+	Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 */
 
 /*
@@ -55,7 +55,13 @@ int32_t insertCluster(struct sClusterChain *chain, u_int32_t cluster) {
 */
 	assert(chain != NULL);
 
-	while (chain->next != NULL) chain=chain->next;
+	while (chain->next != NULL) {
+		if (chain->cluster == cluster) {
+			myerror("Loop in cluster chain detected (%08lx)!", cluster);
+			return -1;
+		}
+		chain=chain->next;
+	}
 
 	if  ((chain->next = malloc(sizeof(struct sClusterChain))) == NULL) {
 		stderror();
