@@ -254,11 +254,13 @@ int32_t cmpEntries(struct sDirEntryList *de1, struct sDirEntryList *de2) {
 		}
 	}
 
-	// consider locale for comparison
-	if ((strxfrm(s1_col, ss1, MAX_PATH_LEN*2) == MAX_PATH_LEN*2) ||
-	    (strxfrm(s2_col, ss2, MAX_PATH_LEN*2) == MAX_PATH_LEN*2)) {
-		myerror("String collation error!");
-		exit(1);
+	if (!OPT_ASCII) {
+		// consider locale for comparison
+		if ((strxfrm(s1_col, ss1, MAX_PATH_LEN*2) == MAX_PATH_LEN*2) ||
+		    (strxfrm(s2_col, ss2, MAX_PATH_LEN*2) == MAX_PATH_LEN*2)) {
+			myerror("String collation error!");
+			exit(1);
+		}
 	}
 
 	//printf("Orig S1: %s, Orig S2: %s, Locale S1: %s, Locale S2: %s\n", ss1, ss2, s1_col, s2_col);
@@ -269,6 +271,13 @@ int32_t cmpEntries(struct sDirEntryList *de1, struct sDirEntryList *de2) {
 		} else {
 			return natstrcmp(ss1, ss2) * OPT_REVERSE;
 		} 
+	} else if (OPT_ASCII) {
+		// use plain ASCII corder
+		if (OPT_IGNORE_CASE) {
+			return strcasecmp(ss1, ss2) * OPT_REVERSE;
+		} else {
+			return strcmp(ss1, ss2) * OPT_REVERSE;
+		}
  	} else {
 		if (OPT_IGNORE_CASE) {
 			return strcasecmp(s1_col, s2_col) * OPT_REVERSE;
