@@ -14,7 +14,7 @@
 
 	You should have received a copy of the GNU General Public License
 	along with this program; if not, write to the Free Software
-	Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+	Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 */
 
 /*
@@ -45,7 +45,7 @@ struct sDirEntryList {
 	char *sname, *lname;		// short and long name strings
 	struct sShortDirEntry *sde;	// short dir entry
 	struct sLongDirEntryList *ldel;	// long name entries in a list
-	int32_t entries;		// number of entries
+	u_int32_t entries;		// number of entries
 	struct sDirEntryList *next;	// next dir entry
 };
 
