@@ -45,49 +45,67 @@
 #include "mallocv.h"
 
 // program information
-#define INFO_PROGRAM "FATSort Utility"
-#define INFO_VERSION "1.1.1"
-#define INFO_AUTHOR "Boris Leidner <fatsort(at)formenos.de>"
-#define INFO_DATE "2004-2013"
-#define INFO_HEADER INFO_PROGRAM " " INFO_VERSION " by " INFO_AUTHOR ", " INFO_DATE "."
-#define INFO_LICENSE	"License GPLv2: GNU GPL version 2 (see LICENSE.txt)\n" \
-			"This is free software: you are free to change and redistribute it.\n" \
-			"There is NO WARRANTY, to the extent permitted by law.\n"
+#define INFO_PROGRAM		"fatsort"
+#define INFO_VERSION		"1.3"
+#define INFO_AUTHOR		"Written by Boris Leidner.\n"
+#define INFO_COPYRIGHT		"Copyright (C) 2004-2014 Boris Leidner.\n"
+#define INFO_LICENSE		"License GPLv2: GNU GPL version 2 (see LICENSE.txt)\n" \
+				"This is free software: you are free to change and redistribute it.\n" \
+				"There is NO WARRANTY, to the extent permitted by law.\n"
+#define INFO_DESCRIPTION	"FATSort sorts directory structures of FAT file systems. " \
+				"Many MP3 hardware players don't sort files automatically " \
+				"but play them in the  order they were transferred to the " \
+				"device. FATSort can help here.\n"
+
+#define INFO_USAGE		"Usage: fatsort [OPTIONS] DEVICE\n" \
+				"\n" \
+				"Options:\n\n" \
+				"\t-a\t Use ASCIIbetical order for sorting\n\n" \
+				"\t-c\t Ignore case of file names\n\n" \
+				"\t-f\t Force sorting even if file system is mounted\n\n" \
+				"\t-h, --help\n\n" \
+				"\t\tPrint some help\n\n" \
+				"\t-i\t Print file system information only\n\n" \
+				"\t-I=PFX\t Ignore file name PFX\n\n" \
+				"\t-l\t Print current order of files only\n\n" \
+				"\t-o=FLAG\t Sort order of files where FLAG is one of\n\n" \
+				"\t\t\td : directories first (default)\n\n" \
+				"\t\t\tf : files first\n\n" \
+				"\t\t\ta : files and directories are not differentiated\n\n" \
+				"\t-n\t Natural order sorting\n\n" \
+				"\t-q\t Be quiet\n\n" \
+				"\t-r\t Sort in reverse order\n\n" \
+				"\t-R\t Sort in random order\n\n" \
+				"\t-t\t Sort by last modification date and time\n\n" \
+				"\t-v, --version\n\n" \
+				"\t\tPrint version information\n\n" \
+				"\tThe following options can be specified multiple times:\n\n" \
+				"\t-d=DIR\t Sort directory DIR only\n\n" \
+				"\t-D=DIR\t Sort directory DIR and all subdirectories\n\n" \
+				"\t-x=DIR\t Don't sort directory DIR\n\n" \
+				"\t-X=DIR\t Don't sort directory DIR and its subdirectories\n\n" \
+				"DEVICE must be a FAT12, FAT16 or FAT32 file system.\n\n" \
+				"WARNING: THE FILESYSTEM MUST BE CONSISTENT, OTHERWISE YOU MAY DAMAGE IT!\n" \
+				"IF SOMEONE ELSE HAS ACCESS TO THE DEVICE HE MIGHT EXPLOIT FATSORT WITH\n" \
+				"A FORGED CORRUPT FILESYSTEM! USE THIS PROGRAM AT YOUR OWN RISK!\n" \
+				"\n" \
+				"Examples:\n" \
+				"\tfatsort /dev/sda\t\tSort /dev/sda.\n" \
+				"\tfatsort -n /dev/sdb1\t\tSort /dev/sdb1 with natural order.\n" \
+				"\n" \
+				"Report bugs to <fatsort@formenos.de>.\n"
+
+#define INFO_OPTION_VERSION	INFO_PROGRAM " " INFO_VERSION "\n" \
+				"\n" \
+				INFO_COPYRIGHT \
+				INFO_LICENSE \
+				"\n" \
+				INFO_AUTHOR
+
+#define INFO_OPTION_HELP	INFO_DESCRIPTION \
+				"\n" \
+				INFO_USAGE
 
-#define INFO_USAGE "\n"	"Usage: fatsort [options] device\n" \
-			"\n" \
-			"Options:\n" \
-			"\t-c\t Ignore case of file names\n" \
-			"\t-f\t Force sorting even if file system is mounted\n" \
-			"\t-h\t Print some help\n" \
-			"\t-i\t Print file system information only\n" \
-			"\t-I pfx\t Ignore file name prefix\n" \
-			"\t-l\t Print current order of files only\n" \
-			"\t-o flag\t Sort order of files where flag is one of\n" \
-			"\t\t\td : directories first (default)\n" \
-			"\t\t\tf : files first\n" \
-			"\t\t\ta : files and directories are not differentiated\n" \
-			"\t-n\t Natural order sorting\n" \
-			"\t-q\t Be quiet\n" \
-			"\t-r\t Sort in reverse order\n" \
-			"\t-R\t Sort in random order\n" \
-			"\t-t\t Sort by last modification date and time\n" \
-			"\t-v\t Print version information\n" \
-			"\n" \
-			"\tThe following options can be specified multiple times:\n" \
-			"\n" \
-			"\t-d dir\t Sort directory dir only\n" \
-			"\t-D dir\t Sort directory dir and all subdirectories\n" \
-			"\t-x dir\t Don't sort directory dir\n" \
-			"\t-X dir\t Don't sort directory dir and its subdirectories\n" \
-			"\n" \
-			"Device must be a FAT12, FAT16 or FAT32 file system.\n" \
-			"\n" \
-			"Example: fatsort /dev/sda\n" \
-			"\n" \
-			"NOTE: THE FILESYSTEM MUST BE CONSISTENT, OTHERWISE YOU MAY DAMAGE IT!\n" \
-			"IF SOMEONE ELSE HAS ACCESS TO THE DEVICE HE MIGHT EXPLOIT FATSORT WITH\n" \
-			"A FORGED CORRUPT FILESYSTEM! USE THIS PROGRAM AT YOUR OWN RISK!\n"
 
 int32_t printFSInfo(char *filename) {
 /*
@@ -112,7 +130,7 @@ int32_t printFSInfo(char *filename) {
 
 	usedClusters=0;
 	badClusters=0;
-	for (i=2; i<fs.clusters; i++) {
+	for (i=2; i<fs.clusters+2; i++) {
 		getFATEntry(&fs, i, &value);
 		if ((value & 0x0FFFFFFF) != 0) usedClusters++;
 		if (fs.FATType == FATTYPE_FAT32) {
@@ -151,7 +169,7 @@ int32_t printFSInfo(char *filename) {
 	if (OPT_MORE_INFO) {
 		printf("\n\t- FAT -\n");
 		printf("Cluster \tFAT entry\tChain length\n");
-		for (i=0; i<fs.clusters; i++) {
+		for (i=0; i<fs.clusters+2; i++) {
 			getFATEntry(&fs, i, &value);
 
 			clen=0;
@@ -200,10 +218,10 @@ int main(int argc, char *argv[]) {
 	}
 
 	if (OPT_HELP) {
-		printf(INFO_HEADER "\n\n" INFO_LICENSE INFO_USAGE);
+		printf(INFO_OPTION_HELP);
 		return 0;
 	} else if (OPT_VERSION) {
-		printf(INFO_HEADER "\n\n" INFO_LICENSE);
+		printf(INFO_OPTION_VERSION);
 		return 0;
 	} else if (optind < argc -1) {
 		myerror("Too many arguments!");
@@ -218,13 +236,13 @@ int main(int argc, char *argv[]) {
 	filename=argv[optind];
 
 	if (OPT_INFO) {
-		infomsg(INFO_HEADER "\n\n");
+		//infomsg(INFO_HEADER "\n\n");
 		if (printFSInfo(filename) == -1) {
 			myerror("Failed to print file system information");
 			return -1;
 		}
 	} else {
-		infomsg(INFO_HEADER "\n\n");
+		//infomsg(INFO_HEADER "\n\n");
 		if (sortFileSystem(filename) == -1) {
 			myerror("Failed to sort file system!");
 			return -1;
