@@ -27,6 +27,7 @@
 #include "errors.h"
 
 #undef malloc
+#undef realloc
 #undef free
 
 int64_t mem_used=0;
@@ -44,7 +45,9 @@ struct sList list={0};
 void add(struct sList *list, void *ptr, size_t size, char *filename, u_int32_t line) {
 
 	assert(list != NULL);
+	assert(ptr != NULL);
 	
+
 	while(list->next != NULL) {
 		list = list->next;
 	}
@@ -58,12 +61,15 @@ void add(struct sList *list, void *ptr, size_t size, char *filename, u_int32_t l
 	list->next->ptr=ptr;
 	list->next->size=size;
 	
-	list->next->file=malloc(strlen(filename)+1);
+	size_t flen=strlen(filename);
+
+	list->next->file=malloc(flen+1);
 	if (list->next->file == NULL) {
 		stderror();
 		exit(1);
 	}
-	strncpy(list->next->file, filename, strlen(filename));
+	strncpy(list->next->file, filename, flen);
+	list->next->file[flen] = '\0';
 	
 	list->next->line=line;
 	
@@ -74,6 +80,7 @@ void add(struct sList *list, void *ptr, size_t size, char *filename, u_int32_t l
 size_t del(struct sList *list, void *ptr) {
 	
 	assert(list != NULL);
+	assert(ptr != NULL);
 	
 	size_t size;
 	struct sList *tmp;
@@ -81,7 +88,7 @@ size_t del(struct sList *list, void *ptr) {
 	while(list->next != NULL) {
 		if (list->next->ptr == ptr) {
 			size=list->next->size;
-			free(list->next->ptr);
+			//free(list->next->ptr);
 			free(list->next->file);
 			tmp=list->next->next;
 			free(list->next);
@@ -96,6 +103,11 @@ size_t del(struct sList *list, void *ptr) {
 void *mallocv(char *filename, u_int32_t line, size_t size) {
 	
 	void* ptr = malloc(size);
+
+	if (size && (ptr == NULL)) {
+		stderror();
+		exit(1);		
+	}
 	
 	add(&list, ptr, size, filename, line);
 	
@@ -108,11 +120,46 @@ void *mallocv(char *filename, u_int32_t line, size_t size) {
 	return ptr;
 }
 
+void *reallocv(char *filename, u_int32_t line, void *ptr, size_t size) {
+	
+	
+	size_t delSize=0;
+
+	if (ptr) {
+		delSize=del(&list, ptr);
+		if (!delSize) {
+#if DEBUG >= 4
+			myerror("No memory allocated for ptr %x freed (realloc) at %s:%u!", ptr, filename, line);
+#endif
+		}
+		mem_used -= delSize;
+	}
+
+	void* newPtr = realloc(ptr, size);
+
+	if (size && (newPtr == NULL)) {
+		stderror();
+		exit(1);		
+	}
+
+	if (newPtr)
+		add(&list, newPtr, size, filename, line);
+	
+	mem_used += size;
+	
+#if DEBUG >= 3
+	myerror("%d bytes reallocated in %s:%u, old ptr=%x, new ptr=%x (total memory %d)!", size-delSize, filename, line, ptr, newPtr, mem_used);
+#endif
+
+	return newPtr;
+}
+
 void freev(char *filename, u_int32_t line, void *ptr) {
 	
 	size_t size=del(&list, ptr);
 	if (size) {
 		mem_used-=size;
+		free(ptr);
 #if DEBUG >= 3		
 		myerror("%d bytes freed in %s:%u (total memory %d)!", size, filename, line, mem_used);
 #endif
@@ -132,3 +179,4 @@ void reportLeaks() {
 	}
 	myerror("Total bytes not freed: %d", mem_used);
 }
+
