@@ -14,7 +14,7 @@
 
 	You should have received a copy of the GNU General Public License
 	along with this program; if not, write to the Free Software
-	Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+	Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 */
 
 /*
@@ -38,11 +38,11 @@ int32_t isDigit(const char c) {
 	return 0;
 }
 
-u_int32_t parseNumber(char **s) {
+int32_t parseNumber(char **s) {
 /*
 	parse integer in string s
 */
-	u_int32_t value=0;
+	int32_t value=0;
 
 	if (!isDigit(**s)) return -1;
 
@@ -61,12 +61,12 @@ int32_t natstrcompare(const char *str1, const char *str2, const u_int32_t respec
 	assert(str1 != NULL);
 	assert(str2 != NULL);
 
-	u_int32_t n1=0, n2=0;
+	int32_t n1=0, n2=0;
 	char *s1 = (char *) str1;
 	char *s2 = (char *) str2;
 
 	while(1) {
-// 		printf("Strings: %s %s\n", s1, s2);
+ 		//printf("Strings: %s %s\n", s1, s2);
 
 		if ((*s1 == '\0') || (*s2 == '\0')) {
 			return strcmp(s1, s2);
@@ -75,7 +75,7 @@ int32_t natstrcompare(const char *str1, const char *str2, const u_int32_t respec
 		// compare characters until the first digit occurs
 		while (1) {
 			if (isDigit(*s1) || isDigit(*s2)) break;
-			else if ((*s1 == '\0') && (*s1 == '\0')) return 0;
+			else if ((*s1 == '\0') && (*s2 == '\0')) return 0;
 			else if ((*s2 == '\0') ||
 				(respectCase ? toupper(*s1) > toupper(*s2) : *s1 > *s2)) return 1;
 			else if ((*s1 == '\0') ||
@@ -87,7 +87,7 @@ int32_t natstrcompare(const char *str1, const char *str2, const u_int32_t respec
 		n1=parseNumber(&s1);
 		n2=parseNumber(&s2);
 
-// 		printf("Numbers: %d %d\n", n1, n2);
+ 		//printf("Numbers: %d %d\n", n1, n2);
 
 		// one of the strings had no number
 		if ((n1 == -1) || (n2 == -1)) {
