@@ -32,7 +32,9 @@
 
 u_int32_t OPT_VERSION, OPT_HELP, OPT_INFO, OPT_QUIET, OPT_IGNORE_CASE,
 	OPT_ORDER, OPT_LIST, OPT_REVERSE, OPT_FORCE, OPT_NATURAL_SORT,
-	OPT_RECURSIVE, OPT_RANDOM, OPT_MORE_INFO, OPT_MODIFICATION;
+	OPT_RECURSIVE, OPT_RANDOM, OPT_MORE_INFO, OPT_MODIFICATION,
+	OPT_ASCII;
+
 struct sStringList *OPT_INCL_DIRS = NULL;
 struct sStringList *OPT_EXCL_DIRS = NULL;
 struct sStringList *OPT_INCL_DIRS_REC = NULL;
@@ -130,6 +132,13 @@ int32_t parse_options(int argc, char *argv[]) {
 
 	int8_t c;
 
+	static struct option longOpts[] = {
+		// name, has_arg, flag, val
+		{"help", 0, 0, 'h'},
+		{"version", 0, 0, 'v'},
+		{0, 0, 0, 0}
+	};
+
 	// no info by default
 	OPT_INFO = 0;
 	OPT_MORE_INFO = 0;
@@ -158,6 +167,9 @@ int32_t parse_options(int argc, char *argv[]) {
 	// sort by last modification time
 	OPT_MODIFICATION = 0;
 
+	// sort by using locale collation order
+	OPT_ASCII = 0;
+
 	// empty string lists for inclusion and exclusion of dirs
 	if ((OPT_INCL_DIRS=newStringList()) == NULL) {
 		myerror("Could not create stringList!");
@@ -187,8 +199,9 @@ int32_t parse_options(int argc, char *argv[]) {
 	}
 
 	opterr=0;
-	while ((c=getopt(argc, argv, "imvhqcfo:lrRnd:D:x:X:I:t")) != -1) {
+	while ((c=getopt_long(argc, argv, "imvhqcfo:lrRnd:D:x:X:I:ta", longOpts, NULL)) != -1) {
 		switch(c) {
+			case 'a' : OPT_ASCII = 1; break;
 			case 'c' : OPT_IGNORE_CASE = 1; break;
 			case 'f' : OPT_FORCE = 1; break;
 			case 'h' : OPT_HELP = 1; break;
