@@ -14,7 +14,7 @@
 
 	You should have received a copy of the GNU General Public License
 	along with this program; if not, write to the Free Software
-	Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+	Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 */
 
 /*
@@ -24,7 +24,6 @@
 #ifndef __platform_h__
 #define __platform_h__
 
-#ifndef __WIN32__
 #if defined(linux) || defined(__linux) || defined(__linux__)
 #undef __LINUX__
 #define __LINUX__	1
@@ -32,23 +31,6 @@
 #undef __BSD__
 #define __BSD__		1
 #endif
-#endif
 
-#ifdef __WIN32__
-#define off_t off64_t
-
-// types defined under Unix but not Windows
-typedef unsigned char u_char;
-typedef unsigned char u_int8_t;
-typedef signed char int8_t;
-typedef unsigned short u_int16_t;
-typedef unsigned int u_int32_t;
-typedef short int int16_t;
-typedef int int32_t;
-// extra header files needed under Windows
-// #include <windows.h>
-// #include <winioctl.h>
-// #include <ctype.h>
-#endif
 
 #endif // __platform_h__
