@@ -14,14 +14,13 @@
 
 	You should have received a copy of the GNU General Public License
 	along with this program; if not, write to the Free Software
-	Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+	Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 */
 
 /*
 	This file contains/describes function for signal handling.
 */
 
-#ifndef __WIN32__
 #include "signal.h"
 
 #include <stdlib.h>
@@ -51,4 +50,3 @@ void end_critical_section(void) {
 	sigprocmask(SIG_UNBLOCK, &blocked_signals_set, NULL);
 }
 
-#endif
