@@ -14,7 +14,7 @@
 
 	You should have received a copy of the GNU General Public License
 	along with this program; if not, write to the Free Software
-	Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+	Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 */
 
 /*
@@ -24,12 +24,6 @@
 #ifndef __signal_h__
 #define __signal_h__
 
-#ifdef __WIN32__
-#define init_signal_handling()
-#define start_critical_section()
-#define end_critical_section()
-#else
-
 // initialize signal handling for critical sections
 void init_signal_handling(void);
 
@@ -39,6 +33,4 @@ void start_critical_section(void);
 // unblocks signals after critical section
 void end_critical_section(void);
 
-#endif
-
 #endif // __signal_h__
