@@ -416,6 +416,9 @@ int32_t writeList(struct sFileSystem *fs, struct sDirEntryList *list) {
 		list=list->next;
 	}
 
+	// sync fs
+	syncFileSystem(fs);
+
 	// end of critical section
 	end_critical_section();
 
@@ -443,7 +446,7 @@ int32_t getClusterChain(struct sFileSystem *fs, u_int32_t startCluster, struct s
 				myerror("Cluster chain is too long!");
 				return -1;
 			}
-			if (cluster >= fs->clusters) {
+			if (cluster >= fs->clusters+2) {
 				myerror("Cluster %08x does not exist!", data);
 				return -1;
 			}
@@ -469,7 +472,7 @@ int32_t getClusterChain(struct sFileSystem *fs, u_int32_t startCluster, struct s
 				myerror("Cluster chain is too long!");
 				return -1;
 			}
-			if (cluster >= fs->clusters) {
+			if (cluster >= fs->clusters+2) {
 				myerror("Cluster %08x does not exist!", data);
 				return -1;
 			}
@@ -495,7 +498,7 @@ int32_t getClusterChain(struct sFileSystem *fs, u_int32_t startCluster, struct s
 				myerror("Cluster chain is too long!");
 				return -1;
 			}
-			if ((cluster & 0x0fffffff) >= fs->clusters) {
+			if ((cluster & 0x0fffffff) >= fs->clusters+2) {
 				myerror("Cluster %08x does not exist!", data);
 				return -1;
 			}
@@ -621,6 +624,9 @@ int32_t writeClusterChain(struct sFileSystem *fs, struct sDirEntryList *list, st
 		}
 	}
 
+	// sync fs
+	syncFileSystem(fs);
+
 	// end of critical section
 	end_critical_section();
 
@@ -819,8 +825,8 @@ int32_t sortFAT1xRootDirectory(struct sFileSystem *fs) {
 			// write the sorted entries back to the fs
 			if (writeList(fs, list) == -1) {
 				freeDirEntryList(list);
-			    myerror("Failed to write root directory entries!");
-			    return -1;
+			  	myerror("Failed to write root directory entries!");
+				return -1;
 			}
 		}
 		
