@@ -14,7 +14,7 @@
 
 	You should have received a copy of the GNU General Public License
 	along with this program; if not, write to the Free Software
-	Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+	Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 */
 
 /*
@@ -27,14 +27,18 @@
 #include <stdlib.h>
 #include <sys/types.h>
 #include "FAT_fs.h"
+#include "clusterchain.h"
 
 // sorts FAT file system
-int32_t sort_fs(char *filename);
+int32_t sortFileSystem(char *filename);
 
-// sorts the root directory of a FAT16 file system
-int32_t sort_FAT16_rootdir(FILE *fd, struct sBootSector *bs);
+// sorts the root directory of a FAT12 or FAT16 file system
+int32_t sortFAT1xRootDirectory(struct sFileSystem *fs);
 
 // sorts directory entries in a cluster
-int32_t sortClusterChain(FILE *fd, struct sBootSector *bs, u_int32_t cluster, char *path);
+int32_t sortClusterChain(struct sFileSystem *fs, u_int32_t cluster, const char (*path)[MAX_PATH_LEN+1]);
+
+// returns cluster chain for a given start cluster
+int32_t getClusterChain(struct sFileSystem *fs, u_int32_t startCluster, struct sClusterChain *chain);
 
 #endif // __sort_h__
